--------------------------------------------------------------------
--	TradeskillSwitcher_HasSpell
--	Boolean for if spell is in spellbook (can include tradeskill window)
--
--	PARAMETERS:
--	ThisSpell - String - Name of spell
--
--	RETURNS:
--	SpellInBook - Boolean - True only if spell is in spellbook.
--
local function TradeskillSwitcher_HasSpell(ThisSpell)
	local retOK = GetSpellInfo(ThisSpell)
	if retOK then return true end
	return false
end

--------------------------------------------------------------------
--	Slash Command: TRADESKILLSWITCHER
--	Cycles through available tradeskill windows
--
--	PARAMETERS:
--	msg - parameters supplied on line with slash command. Used to
--		  determine if conditionals have been supplied and if pass.
--	editbox - Unused. Required by slash command functions.
--
SLASH_TRADESKILLSWITCHER1 = "/tsswitch"
SLASH_TRADESKILLSWITCHER2 = "/tradeskillswitcher"
function SlashCmdList.TRADESKILLSWITCHER(msg, editbox)
	local L = TradeskillSwitcherLocalizations
	local tsArgv, _ = SecureCmdOptionParse(msg)
	if (tsArgv == nil) then return end

	local TSNum = 0
	local TStoOpen = ""
	--local OpenTS = GetTradeSkillLine() -- DEPRECATED
	
	-- Set tradeskill names to reversible array
	local TSvsNum = {}
	TSvsNum[1] = L.ALCHEMY
	TSvsNum[2] = L.BLACKSMITHING
	TSvsNum[3] = L.TAILORING
	TSvsNum[4] = L.ENGINEERING
	TSvsNum[5] = L.LEATHERWORKING
	TSvsNum[6] = L.JEWELCRAFTING
	TSvsNum[7] = L.INSCRIPTION
	TSvsNum[8] = L.ENCHANTING
	TSvsNum[9] = L.MINING
	TSvsNum[10] = L.COOKING
	TSvsNum[11] = L.FIRSTAID
	TSvsNum[12] = L.ARCHAEOLOGY
	TSvsNum[13] = L.RUNEFORGING
	for i=1, getn(TSvsNum) do TSvsNum[TSvsNum[i]] = i end

	-- Determines which, if any, tradeskill window is open
	--if (OpenTS ~= "UNKNOWN") then TSNum = TSvsNum[OpenTS]
	--elseif (ArchaeologyFrame and ArchaeologyFrame:IsVisible()) then TSNum = TSvsNum[L.ARCHAEOLOGY]
	--else TSNum = 0
	--end
	if (ArchaeologyFrame and ArchaeologyFrame:IsVisible()) then TSNum = TSvsNum[L.ARCHAEOLOGY]
	elseif (not TradeSkillFrame or not TradeSkillFrame:IsVisible()) then TSNum = 0
	else
		local currentTSName = TradeSkillFrameTitleText:GetText()
		TSNum = TSvsNum[currentTSName]
	end

	-- Determines next available tradeskill in list to open
	TSNum = TSNum + 1
	for TSCounter = TSNum, 13 do
		if (TStoOpen == "") then 
			local spellName = TSvsNum[TSCounter]
			if spellName == L.MINING then spellName = L.SMELTING end
			if TradeskillSwitcher_HasSpell(spellName) then TStoOpen = spellName end
		end
	end

	-- Opens that tradeskill window, or if no tradeskill is found before end of list, closes all tradeskill windows
	if (TStoOpen == L.ARCHAEOLOGY) then TradeSkillFrame:Hide() end
	if (TStoOpen ~= L.ARCHAEOLOGY and ArchaeologyFrame and ArchaeologyFrame:IsVisible()) then HideUIPanel(ArchaeologyFrame) end
	if (TStoOpen ~= "") then
		--if TradeSkillFrame and TradeSkillFrame:IsVisible() then TradeSkillFrame:Hide() end
		CastSpellByName(TStoOpen)
	else
		TradeSkillFrame:Hide()
	end
end